@@ -121,8 +121,12 @@ class ControllerAPI:
         req_id = str(uuid.uuid4())
         config_update = {"jsonrpc":"2.0","id":req_id,"config":{}}
         config_update['config'][key] = value
-        self.__pelion_put(req_id,self.pelion_config_lwm2m_uri,config_update)
-        return self.pelion_get_config()
+        result = self.__pelion_put(req_id,self.pelion_config_lwm2m_uri,config_update)
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_get_config()
+        else:
+            print("PelionSageAPI (PUT) set_config FAILED with status: " + result.status_code)
+            return result
 
     #
     # Sagemaker Controls
